@@ -15,15 +15,14 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with eofs.  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
+from __future__ import (absolute_import, division, print_function)  # noqa
 
-from nose import SkipTest
-from nose.tools import raises
 import numpy as np
 try:
     import cdms2
 except ImportError:
     pass
+import pytest
 
 import eofs
 from eofs.tests import EofsTest
@@ -56,46 +55,46 @@ class ErrorHandlersTest(EofsTest):
         try:
             cls.solution = reference_solution(cls.interface, cls.weights)
         except ValueError:
-            raise SkipTest('library component not available '
-                           'for {!s} interface'.format(cls.interface))
+            pytest.skip('missing dependencies required to test '
+                        'the {!s} interface'.format(cls.interface))
         cls.neofs = cls.solution['eigenvalues'].shape[0]
         try:
             cls.solver = solvers[cls.interface](
                 cls.solution['sst'], weights=cls.solution['weights'])
         except KeyError:
-            raise SkipTest('library component not available '
-                           'for {!s} interface'.format(cls.interface))
+            pytest.skip('missing dependencies required to test '
+                        'the {!s} interface'.format(cls.interface))
 
-    @raises(ValueError)
     def test_invalid_pcscaling(self):
         # PCs with invalid scaling
-        pcs = self.solver.pcs(pcscaling=-1)
+        with pytest.raises(ValueError):
+            pcs = self.solver.pcs(pcscaling=-1)
 
-    @raises(ValueError)
     def test_invalid_eofscaling(self):
         # EOFs with invalid scaling
-        eofs = self.solver.eofs(eofscaling=-1)
+        with pytest.raises(ValueError):
+            eofs = self.solver.eofs(eofscaling=-1)
 
-    @raises(ValueError)
     def test_projectField_invalid_dimensions(self):
         # projecting a field with too few dimensions
         data = self.solution['sst'][:, 0, 0]
-        pcs = self.solver.projectField(data)
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
-    @raises(ValueError)
     def test_projectField_invalid_shape(self):
         # projecting a field with the wrong shape
         data = self.solution['sst'][..., 0:1]
-        pcs = self.solver.projectField(data)
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
-    @raises(ValueError)
     def test_projectField_different_missing_values(self):
         # projecting a field with different missing values
         solution = reference_solution(self.interface, self.weights)
         data = solution['sst']
         mask = data.mask
         mask[0] = True
-        pcs = self.solver.projectField(data)
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
 
 # ----------------------------------------------------------------------------
@@ -116,11 +115,11 @@ class TestErrorHandlersCDMS(ErrorHandlersTest):
     interface = 'cdms'
     weights = 'equal'
 
-    @raises(TypeError)
     def test_projectField_invalid_type(self):
         # projecting a field of the wrong type
         solution = reference_solution('standard', 'equal')
-        pcs = self.solver.projectField(solution['sst'])
+        with pytest.raises(TypeError):
+            pcs = self.solver.projectField(solution['sst'])
 
 
 # ----------------------------------------------------------------------------
@@ -132,28 +131,28 @@ class TestErrorHandlersIris(ErrorHandlersTest):
     interface = 'iris'
     weights = 'equal'
 
-    @raises(TypeError)
     def test_projectField_invalid_type(self):
         # projecting a field of the wrong type
         solution = reference_solution('standard', 'equal')
-        pcs = self.solver.projectField(solution['sst'])
+        with pytest.raises(TypeError):
+            pcs = self.solver.projectField(solution['sst'])
 
-    @raises(ValueError)
     def test_projectField_different_missing_values(self):
         # projecting a field with different missing values
         solution = reference_solution(self.interface, self.weights)
         data = solution['sst']
         mask = data.data.mask
         mask[0] = True
-        pcs = self.solver.projectField(data)
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
-    @raises(ValueError)
     def test_projectField_invalid_dimension_order(self):
         # projecting a field with the time dimension not at the front
         solution = reference_solution(self.interface, self.weights)
         data = solution['sst']
         data.transpose((2, 1, 0))
-        pcs = self.solver.projectField(data)
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
 
 # ----------------------------------------------------------------------------
@@ -165,27 +164,27 @@ class TestErrorHandlersXarray(ErrorHandlersTest):
     interface = 'xarray'
     weights = 'equal'
 
-    @raises(TypeError)
     def test_projectField_invalid_type(self):
         # projecting a field of the wrong type
         solution = reference_solution('standard', 'equal')
-        pcs = self.solver.projectField(solution['sst'])
+        with pytest.raises(TypeError):
+            pcs = self.solver.projectField(solution['sst'])
 
-    @raises(ValueError)
     def test_projectField_different_missing_values(self):
         # projecting a field with different missing values
         solution = reference_solution(self.interface, self.weights)
         data = solution['sst']
         data.values[0] = np.nan
-        pcs = self.solver.projectField(data)
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
-    @raises(ValueError)
     def test_projectField_invalid_dimension_order(self):
         # projecting a field with the time dimension not at the front
         solution = reference_solution(self.interface, self.weights)
         data = solution['sst']
-        data.transpose((2, 1, 0))
-        pcs = self.solver.projectField(data)
+        data = data.transpose('longitude', 'latitude', 'time')
+        with pytest.raises(ValueError):
+            pcs = self.solver.projectField(data)
 
 
 # ----------------------------------------------------------------------------
@@ -199,30 +198,29 @@ class TestConstructorStandard(EofsTest):
     def setup_class(cls):
         cls.solver_class = solvers['standard']
 
-    @raises(ValueError)
     def test_invalid_input_dimensions(self):
         # too few input dimensions
         solution = reference_solution('standard', 'equal')
         data = solution['sst'][:, 0, 0]
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_invalid_weights_dimensions(self):
         # weights with incompatible dimensions
         solution = reference_solution('standard', 'area')
         data = solution['sst']
         weights = solution['weights'][:, 0]
-        solver = self.solver_class(data, weights=weights)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights=weights)
 
-    @raises(TypeError)
     def test_invalid_weights_type(self):
         # weights with an incompatible type
         solution = reference_solution('standard', 'area')
         data = solution['sst']
         weights = 'area'
-        solver = self.solver_class(data, weights=weights)
+        with pytest.raises(TypeError):
+            solver = self.solver_class(data, weights=weights)
 
-    @raises(ValueError)
     def test_input_with_all_missing_values(self):
         # input with only missing values, missing values are propagated
         # because the default for the center argument is True
@@ -230,9 +228,9 @@ class TestConstructorStandard(EofsTest):
         data = solution['sst']
         mask = data.mask
         mask[-1] = True
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_with_non_uniform_missing_values(self):
         # missing values in different places at different times leads to
         # errors in computing the SVD
@@ -240,7 +238,8 @@ class TestConstructorStandard(EofsTest):
         data = solution['sst']
         mask = data.mask
         mask[-1] = True
-        solver = self.solver_class(data, center=False)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, center=False)
 
 
 # ----------------------------------------------------------------------------
@@ -255,60 +254,59 @@ class TestConstructorCDMS(EofsTest):
         try:
             cls.solver_class = solvers['cdms']
         except KeyError:
-            raise SkipTest('library component not available '
-                           'for cdms interface')
+            pytest.skip('missing dependencies required to test the '
+                        'cdms interface')
 
-    @raises(TypeError)
     def test_wrong_input_type(self):
         # input of the wrong type
         solution = reference_solution('standard', 'equal')
         data = solution['sst']
-        solver = self.solver_class(data)
+        with pytest.raises(TypeError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_without_time_dimension(self):
         # no time dimension in the input
         solution = reference_solution('cdms', 'equal')
         data = solution['sst'](time=slice(0, 1), squeeze=True)
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_time_dimension_not_first(self):
         # time not the first dimension in the input
         solution = reference_solution('cdms', 'equal')
         data = solution['sst']
         data = data.reorder('xyt')
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_no_spatial_dimensions(self):
         # not enough dimensions in the input
         solution = reference_solution('cdms', 'equal')
         data = solution['sst'][:, 0, 0]
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_invalid_builtin_weights_value(self):
         # invalid weighting scheme name
         solution = reference_solution('cdms', 'equal')
         data = solution['sst']
-        solver = self.solver_class(data, weights='invalid')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='invalid')
 
-    @raises(ValueError)
     def test_builtin_latitude_weights_with_missing_dimension(self):
         # latitude weights without latitude dimension
         solution = reference_solution('cdms', 'equal')
         data = solution['sst'](latitude=slice(0, 1), squeeze=True)
-        solver = self.solver_class(data, weights='coslat')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='coslat')
 
-    @raises(ValueError)
     def test_builtin_area_weights_with_missing_dimension(self):
         # area weights without longitude dimension
         solution = reference_solution('cdms', 'equal')
         data = solution['sst'](longitude=slice(0, 1), squeeze=True)
-        solver = self.solver_class(data, weights='area')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='area')
 
-    @raises(ValueError)
     def test_builtin_area_weights_with_non_adjacent_dimensions(self):
         # area weights with latitude and longitude not adjacent in input
         solution = reference_solution('cdms', 'equal')
@@ -319,7 +317,8 @@ class TestConstructorCDMS(EofsTest):
                                     axes=data.getAxisList() + [newdim],
                                     id=data.id)
         data = data.reorder('txzy')
-        solver = self.solver_class(data, weights='area')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='area')
 
 
 # ----------------------------------------------------------------------------
@@ -334,62 +333,61 @@ class TestConstructorIris(EofsTest):
         try:
             cls.solver_class = solvers['iris']
         except KeyError:
-            raise SkipTest('library component not available '
-                           'for iris interface')
+            pytest.skip('missing dependencies required to test the '
+                        'iris interface')
 
-    @raises(TypeError)
     def test_wrong_input_type(self):
         # input of the wrong type
         solution = reference_solution('standard', 'equal')
         data = solution['sst']
-        solver = self.solver_class(data)
+        with pytest.raises(TypeError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_without_time_dimension(self):
         # no time dimension in the input
         solution = reference_solution('iris', 'equal')
         data = solution['sst'][0]
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_time_dimension_not_first(self):
         # time not the first dimension in the input
         solution = reference_solution('iris', 'equal')
         data = solution['sst']
         data.transpose((2, 1, 0))
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_no_spatial_dimensions(self):
         # not enough dimensions in the input
         solution = reference_solution('iris', 'equal')
         data = solution['sst'][:, 0, 0]
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_invalid_builtin_weights_value(self):
         # invalid weighting scheme name
         solution = reference_solution('iris', 'equal')
         data = solution['sst']
-        solver = self.solver_class(data, weights='invalid')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='invalid')
 
-    @raises(ValueError)
     def test_builtin_latitude_weights_with_missing_dimension(self):
         # latitude weights without latitude dimension
         solution = reference_solution('iris', 'latitude')
         data = solution['sst'][:, 0, :]
         data.remove_coord('latitude')
-        solver = self.solver_class(data, weights='coslat')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='coslat')
 
-    @raises(ValueError)
     def test_builtin_area_weights_with_missing_dimension(self):
         # latitude weights without latitude dimension
         solution = reference_solution('iris', 'area')
         data = solution['sst'][:, :, 0]
         data.remove_coord('longitude')
-        solver = self.solver_class(data, weights='area')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='area')
 
-    @raises(ValueError)
     def test_multiple_time_dimensions(self):
         # multiple dimensions representing time
         solution = reference_solution('iris', 'equal')
@@ -397,7 +395,8 @@ class TestConstructorIris(EofsTest):
         lon = data.coord('longitude')
         lon.rename('time')
         lon.units = 'days since 1999-01-01 00:00:0.0'
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
 
 # ----------------------------------------------------------------------------
@@ -412,49 +411,49 @@ class TestConstructorXarray(EofsTest):
         try:
             cls.solver_class = solvers['xarray']
         except KeyError:
-            raise SkipTest('library component not available '
-                           'for iris interface')
+            pytest.skip('missing dependencies required to test the '
+                        'xarray interface')
 
-    @raises(TypeError)
     def test_wrong_input_type(self):
         # input of the wrong type
         solution = reference_solution('standard', 'equal')
         data = solution['sst']
-        solver = self.solver_class(data)
+        with pytest.raises(TypeError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_without_time_dimension(self):
         # no time dimension in the input
         solution = reference_solution('xarray', 'equal')
         data = solution['sst'][0]
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_time_dimension_not_first(self):
         # time not the first dimension in the input
         solution = reference_solution('xarray', 'equal')
         data = solution['sst']
-        data.transpose((2, 1, 0))
-        solver = self.solver_class(data)
+        data = data.transpose('longitude', 'latitude', 'time')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_input_no_spatial_dimensions(self):
         # not enough dimensions in the input
         solution = reference_solution('xarray', 'equal')
         data = solution['sst'][:, 0, 0]
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
 
-    @raises(ValueError)
     def test_invalid_builtin_weights_value(self):
         # invalid weighting scheme name
         solution = reference_solution('xarray', 'equal')
         data = solution['sst']
-        solver = self.solver_class(data, weights='invalid')
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data, weights='invalid')
 
-    @raises(ValueError)
     def test_multiple_time_dimensions(self):
         # multiple dimensions representing time
         solution = reference_solution('xarray', 'equal')
         data = solution['sst']
         data.coords['longitude'].attrs['axis'] = 'T'
-        solver = self.solver_class(data)
+        with pytest.raises(ValueError):
+            solver = self.solver_class(data)
