@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with eofs.  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
+from __future__ import (absolute_import, division, print_function)  # noqa
 
 import collections
 
@@ -174,8 +174,8 @@ class Eof(object):
 
         """
         pcs = self._solver.pcs(pcscaling, npcs)
-        pcdim = xr.Coordinate('mode', range(pcs.shape[1]),
-                              attrs={'long_name': 'eof_mode_number'})
+        pcdim = xr.IndexVariable('mode', range(pcs.shape[1]),
+                                 attrs={'long_name': 'eof_mode_number'})
         coords = [self._time, pcdim]
         pcs = xr.DataArray(pcs, coords=coords, name='pcs')
         pcs.coords.update({coord.name: ('time', coord)
@@ -220,8 +220,8 @@ class Eof(object):
 
         """
         eofs = self._solver.eofs(eofscaling, neofs)
-        eofdim = xr.Coordinate('mode', range(eofs.shape[0]),
-                               attrs={'long_name': 'eof_mode_number'})
+        eofdim = xr.IndexVariable('mode', range(eofs.shape[0]),
+                                  attrs={'long_name': 'eof_mode_number'})
         coords = [eofdim] + self._coords
         long_name = 'empirical_orthogonal_functions'
         eofs = xr.DataArray(eofs, coords=coords, name='eofs',
@@ -267,8 +267,8 @@ class Eof(object):
 
         """
         eofs = self._solver.eofsAsCorrelation(neofs)
-        eofdim = xr.Coordinate('mode', range(eofs.shape[0]),
-                               attrs={'long_name': 'eof_mode_number'})
+        eofdim = xr.IndexVariable('mode', range(eofs.shape[0]),
+                                  attrs={'long_name': 'eof_mode_number'})
         coords = [eofdim] + self._coords
         long_name = 'correlation_between_pcs_and_{!s}'.format(self._name)
         eofs = xr.DataArray(eofs, coords=coords, name='eofs',
@@ -327,8 +327,8 @@ class Eof(object):
 
         """
         eofs = self._solver.eofsAsCovariance(neofs, pcscaling)
-        eofdim = xr.Coordinate('mode', range(eofs.shape[0]),
-                               attrs={'long_name': 'eof_mode_number'})
+        eofdim = xr.IndexVariable('mode', range(eofs.shape[0]),
+                                  attrs={'long_name': 'eof_mode_number'})
         coords = [eofdim] + self._coords
         long_name = 'covariance_between_pcs_and_{!s}'.format(self._name)
         eofs = xr.DataArray(eofs, coords=coords, name='eofs',
@@ -367,8 +367,8 @@ class Eof(object):
 
         """
         lambdas = self._solver.eigenvalues(neigs=neigs)
-        eofdim = xr.Coordinate('mode', range(lambdas.shape[0]),
-                               attrs={'long_name': 'eof_mode_number'})
+        eofdim = xr.IndexVariable('mode', range(lambdas.shape[0]),
+                                  attrs={'long_name': 'eof_mode_number'})
         coords = [eofdim]
         long_name = 'eigenvalues'
         lambdas = xr.DataArray(lambdas, coords=coords, name='eigenvalues',
@@ -409,8 +409,8 @@ class Eof(object):
 
         """
         vf = self._solver.varianceFraction(neigs=neigs)
-        eofdim = xr.Coordinate('mode', range(vf.shape[0]),
-                               attrs={'long_name': 'eof_mode_number'})
+        eofdim = xr.IndexVariable('mode', range(vf.shape[0]),
+                                  attrs={'long_name': 'eof_mode_number'})
         coords = [eofdim]
         long_name = 'variance_fractions'
         vf = xr.DataArray(vf, coords=coords, name='variance_fractions',
@@ -483,8 +483,8 @@ class Eof(object):
 
         """
         typerrs = self._solver.northTest(neigs=neigs, vfscaled=vfscaled)
-        eofdim = xr.Coordinate('mode', range(typerrs.shape[0]),
-                               attrs={'long_name': 'eof_mode_number'})
+        eofdim = xr.IndexVariable('mode', range(typerrs.shape[0]),
+                                  attrs={'long_name': 'eof_mode_number'})
         coords = [eofdim]
         long_name = 'typical_errors'
         typerrs = xr.DataArray(typerrs, coords=coords, name='typical_errors',
@@ -621,15 +621,15 @@ class Eof(object):
                                         weighted=weighted)
         # Create the PCs DataArray.
         if pcs.ndim == 2:
-            pcdim = xr.Coordinate('mode', range(pcs.shape[1]),
-                                  attrs={'long_name': 'eof_mode_number'})
+            pcdim = xr.IndexVariable('mode', range(pcs.shape[1]),
+                                     attrs={'long_name': 'eof_mode_number'})
             pcs = xr.DataArray(
                 pcs,
                 coords=[time_coord, pcdim], name='pseudo_pcs',
                 attrs={'long_name': '{}_pseudo_pcs'.format(array_name)})
         else:
-            pcdim = xr.Coordinate('mode', range(pcs.shape[0]),
-                                  attrs={'long_name': 'eof_mode_number'})
+            pcdim = xr.IndexVariable('mode', range(pcs.shape[0]),
+                                     attrs={'long_name': 'eof_mode_number'})
             pcs = xr.DataArray(
                 pcs,
                 coords=[pcdim], name='pseudo_pcs',
@@ -637,7 +637,7 @@ class Eof(object):
         if has_time:
             # Add non-dimension coordinates.
             pcs.coords.update({coord.name: (coord.dims, coord)
-                               for coord in self._time_ndcoords})
+                               for coord in time_ndcoords})
         return pcs
 
     def getWeights(self):
